@@ -43,6 +43,7 @@ std::string getVecKeyword(GpuLanguage lang)
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -56,7 +57,7 @@ std::string getVecKeyword(GpuLanguage lang)
         }
 
         case GPU_LANGUAGE_MSL_2_0:
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << "float" << N;
             break;
@@ -80,7 +81,9 @@ void getTexDecl(GpuLanguage lang,
                 const std::string & textureName, 
                 const std::string & samplerName,
                 std::string & textureDecl, 
-                std::string & samplerDecl)
+                std::string & samplerDecl,
+                unsigned descriptorSetIndex,
+                unsigned textureIndex)
 {
     switch (lang)
     {
@@ -98,7 +101,17 @@ void getTexDecl(GpuLanguage lang,
             samplerDecl = kw.str();
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
+        {
+            textureDecl = "";
+
+            std::ostringstream kw;
+            kw << "layout(set=" << descriptorSetIndex << ", binding = " << textureIndex << ") ";
+            kw << "uniform sampler" << N << "D " << samplerName << "; ";
+            samplerDecl = kw.str();
+            break;
+        }
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             std::ostringstream t;
             t << "Texture" << N << "D " << textureName << ";";
@@ -166,12 +179,13 @@ std::string getTexSample(GpuLanguage lang,
             kw << "tex" << N << "D(" << samplerName << ", " << coords << ")";
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << textureName << ".Sample(" << samplerName << ", " << coords << ")";
             break;
         }
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         {
             kw << "texture(" << samplerName << ", " << coords << ")";
             break;
@@ -337,6 +351,7 @@ std::string GpuShaderText::constKeyword() const
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_MSL_2_0:
@@ -345,7 +360,7 @@ std::string GpuShaderText::constKeyword() const
             str += " ";
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             str += "static const";
             str += " ";
@@ -513,45 +528,54 @@ void GpuShaderText::declareFloatArrayConst(const std::string & name, int size, c
     }
 
     auto nl = newLine();
+    
+    auto emitArrayValues = [&]()
+    {
+        for (int i = 0; i < size; ++i)
+        {
+            nl << getFloatString(v[i], m_lang);
+            if (i + 1 != size)
+            {
+                nl << ", ";
+            }
+        }
+    };
 
     switch (m_lang)
     {
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
             nl << floatKeywordConst() << " " << name << "[" << size << "] = ";
             nl << floatKeyword() << "[" << size << "](";
-            for (int i = 0; i < size; ++i)
-            {
-                nl << getFloatString(v[i], m_lang);
-                if (i + 1 != size)
-                {
-                    nl << ", ";
-                }
-            }
+            emitArrayValues();
             nl << ");";
             break;
         }
         case LANGUAGE_OSL_1:
         case GPU_LANGUAGE_CG:
-        case GPU_LANGUAGE_HLSL_DX11:
-        case GPU_LANGUAGE_MSL_2_0:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
-            nl << floatKeywordConst() << " " << name << "[" << size << "] = {";
-            for (int i = 0; i < size; ++i)
-            {
-                nl << getFloatString(v[i], m_lang);
-                if (i + 1 != size)
-                {
-                    nl << ", ";
-                }
-            }
+            nl << floatKeywordConst();
+            nl << " " << name << "[" << size << "] = {";
+            emitArrayValues();
             nl << "};";
             break;
         }
+            
+        case GPU_LANGUAGE_MSL_2_0:
+        {
+            nl << "constant constexpr static float";
+            nl << " " << name << "[" << size << "] = {";
+            emitArrayValues();
+            nl << "};";
+            break;
+        }
+            
     }
 }
 
@@ -567,40 +591,47 @@ void GpuShaderText::declareIntArrayConst(const std::string & name, int size, con
     }
 
     auto nl = newLine();
+    
+    auto emitArrayValues = [&]()
+    {
+        for (int i = 0; i < size; ++i)
+        {
+            nl << v[i];
+            if (i + 1 != size)
+            {
+                nl << ", ";
+            }
+        }
+    };
 
     switch (m_lang)
     {
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
             nl << intKeywordConst() << " " << name << "[" << size << "] = "
                << intKeyword() << "[" << size << "](";
-            for (int i = 0; i < size; ++i)
-            {
-                nl << v[i];
-                if (i + 1 != size)
-                {
-                    nl << ", ";
-                }
-            }
+            emitArrayValues();
             nl << ");";
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
+        {
+            nl << intKeywordConst();
+            nl << " " << name << "[" << size << "] = {";
+            emitArrayValues();
+            nl << "};";
+            break;
+        }
         case GPU_LANGUAGE_MSL_2_0:
         {
-            nl << intKeywordConst() << " " << name << "[" << size << "] = {";
-            for (int i = 0; i < size; ++i)
-            {
-                nl << v[i];
-                if (i + 1 != size)
-                {
-                    nl << ", ";
-                }
-            }
+            nl << "constant constexpr static int";
+            nl << " " << name << "[" << size << "] = {";
+            emitArrayValues();
             nl << "};";
             break;
         }
@@ -608,14 +639,7 @@ void GpuShaderText::declareIntArrayConst(const std::string & name, int size, con
         case GPU_LANGUAGE_CG:
         {
             nl << intKeyword() << " " << name << "[" << size << "] = {";
-            for (int i = 0; i < size; ++i)
-            {
-                nl << v[i];
-                if (i + 1 != size)
-                {
-                    nl << ", ";
-                }
-            }
+            emitArrayValues();
             nl << "};";
             break;
         }
@@ -819,10 +843,13 @@ std::string GpuShaderText::getSamplerName(const std::string& textureName)
     return textureName + "Sampler";
 }
 
-void GpuShaderText::declareTex1D(const std::string & textureName)
+void GpuShaderText::declareTex1D(const std::string & textureName,
+                                 unsigned descriptorSetIndex, 
+                                 unsigned textureIndex)
 {
     std::string textureDecl, samplerDecl;
-    getTexDecl<1>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl);
+    getTexDecl<1>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl,
+                  descriptorSetIndex, textureIndex);
 
     if (!textureDecl.empty())
     {
@@ -835,10 +862,13 @@ void GpuShaderText::declareTex1D(const std::string & textureName)
     }
 }
 
-void GpuShaderText::declareTex2D(const std::string & textureName)
+void GpuShaderText::declareTex2D(const std::string & textureName,
+                                 unsigned descriptorSetIndex,
+                                 unsigned textureIndex)
 {
     std::string textureDecl, samplerDecl;
-    getTexDecl<2>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl);
+    getTexDecl<2>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl,
+                  descriptorSetIndex, textureIndex);
 
     if (!textureDecl.empty())
     {
@@ -851,10 +881,13 @@ void GpuShaderText::declareTex2D(const std::string & textureName)
     }
 }
 
-void GpuShaderText::declareTex3D(const std::string& textureName)
+void GpuShaderText::declareTex3D(const std::string& textureName,
+                                 unsigned descriptorSetIndex,
+                                 unsigned textureIndex)
 {
     std::string textureDecl, samplerDecl;
-    getTexDecl<3>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl);
+    getTexDecl<3>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl,
+                  descriptorSetIndex, textureIndex);
 
     if (!textureDecl.empty())
     {
@@ -888,27 +921,58 @@ std::string GpuShaderText::sampleTex3D(const std::string& textureName,
 
 void GpuShaderText::declareUniformFloat(const std::string & uniformName)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << floatKeyword() << " " << uniformName << ";";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << floatKeyword() << " " << uniformName << ";";
 }
 
 void GpuShaderText::declareUniformBool(const std::string & uniformName)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << "bool " << uniformName << ";";
+    std::string uniformDeclString("uniform ");
+    std::string boolKeyword("bool");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0)
+    {
+        uniformDeclString = "";
+    }
+    else if (m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+        boolKeyword = "int";
+    }
+    newLine() << uniformDeclString << boolKeyword << " " << uniformName << ";";
 }
 
 void GpuShaderText::declareUniformFloat3(const std::string & uniformName)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << float3Keyword() << " " << uniformName << ";";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << float3Keyword() << " " << uniformName << ";";
 }
 
 void GpuShaderText::declareUniformArrayFloat(const std::string & uniformName, unsigned int size)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << floatKeyword() << " " << uniformName << "[" << size << "];";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << floatKeyword() << " " << uniformName << "[" << size << "];";
 }
 
 void GpuShaderText::declareUniformArrayInt(const std::string & uniformName, unsigned int size)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << intKeyword() << " " << uniformName << "[" << size << "];";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << intKeyword() << " " << uniformName << "[" << size << "];";
 }
 
 // Keep the method private as only float & double types are expected
@@ -926,6 +990,7 @@ std::string matrix3Mul(const T * m3x3, const std::string & vecName, GpuLanguage
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -940,7 +1005,7 @@ std::string matrix3Mul(const T * m3x3, const std::string & vecName, GpuLanguage
                 << getMatrixValues<T, 3>(m3x3, lang, false) << "), " << vecName << ")";
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << "mul(" << vecName
                 << ", float3x3(" << getMatrixValues<T, 3>(m3x3, lang, true) << "))";
@@ -948,7 +1013,7 @@ std::string matrix3Mul(const T * m3x3, const std::string & vecName, GpuLanguage
         }
         case LANGUAGE_OSL_1:
         {
-            kw << "matrix(" << getMatrixValues<T, 3>(m3x3, lang, false) << ") * " << vecName;
+            kw << "matrix(" << getMatrixValues<T, 3>(m3x3, lang, true) << ") * " << vecName;
             break;
         }
         case GPU_LANGUAGE_MSL_2_0:
@@ -992,6 +1057,7 @@ std::string matrix4Mul(const T * m4x4, const std::string & vecName, GpuLanguage
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -1006,7 +1072,7 @@ std::string matrix4Mul(const T * m4x4, const std::string & vecName, GpuLanguage
                 << getMatrixValues<T, 4>(m4x4, lang, false) << "), " << vecName << ")";
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << "mul(" << vecName 
                 << ", float4x4(" << getMatrixValues<T, 4>(m4x4, lang, true) << "))";
@@ -1014,7 +1080,7 @@ std::string matrix4Mul(const T * m4x4, const std::string & vecName, GpuLanguage
         }
         case LANGUAGE_OSL_1:
         {
-            kw << "matrix(" << getMatrixValues<T, 4>(m4x4, lang, false) << ") * " << vecName;
+            kw << "matrix(" << getMatrixValues<T, 4>(m4x4, lang, true) << ") * " << vecName;
             break;
         }
         case GPU_LANGUAGE_MSL_2_0:
@@ -1054,6 +1120,7 @@ std::string GpuShaderText::lerp(const std::string & x,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_MSL_2_0:
@@ -1062,7 +1129,7 @@ std::string GpuShaderText::lerp(const std::string & x,
             break;
         }
         case GPU_LANGUAGE_CG:
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << "lerp(" << x << ", " << y << ", " << a << ")";
             break;
@@ -1085,6 +1152,7 @@ std::string GpuShaderText::float3GreaterThan(const std::string & a,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_CG:
@@ -1094,7 +1162,7 @@ std::string GpuShaderText::float3GreaterThan(const std::string & a,
         }
         case LANGUAGE_OSL_1:
         case GPU_LANGUAGE_MSL_2_0:
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << float3Keyword() << "(" 
                << "(" << a << "[0] > " << b << "[0]) ? 1.0 : 0.0, "
@@ -1120,6 +1188,7 @@ std::string GpuShaderText::float4GreaterThan(const std::string & a,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_CG:
@@ -1128,7 +1197,7 @@ std::string GpuShaderText::float4GreaterThan(const std::string & a,
             break;
         }
         case GPU_LANGUAGE_MSL_2_0:
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             kw << float4Keyword() << "(" 
                << "(" << a << "[0] > " << b << "[0]) ? 1.0 : 0.0, "
@@ -1164,6 +1233,7 @@ std::string GpuShaderText::float3GreaterThanEqual(const std::string& a,
     case GPU_LANGUAGE_GLSL_1_2:
     case GPU_LANGUAGE_GLSL_1_3:
     case GPU_LANGUAGE_GLSL_4_0:
+    case GPU_LANGUAGE_GLSL_VK_4_6:
     case GPU_LANGUAGE_GLSL_ES_1_0:
     case GPU_LANGUAGE_GLSL_ES_3_0:
     case GPU_LANGUAGE_CG:
@@ -1173,7 +1243,7 @@ std::string GpuShaderText::float3GreaterThanEqual(const std::string& a,
     }
     case LANGUAGE_OSL_1:
     case GPU_LANGUAGE_MSL_2_0:
-    case GPU_LANGUAGE_HLSL_DX11:
+    case GPU_LANGUAGE_HLSL_SM_5_0:
     {
         kw << float3Keyword() << "("
             << "(" << a << "[0] >= " << b << "[0]) ? 1.0 : 0.0, "
@@ -1199,6 +1269,7 @@ std::string GpuShaderText::float4GreaterThanEqual(const std::string& a,
     case GPU_LANGUAGE_GLSL_1_2:
     case GPU_LANGUAGE_GLSL_1_3:
     case GPU_LANGUAGE_GLSL_4_0:
+    case GPU_LANGUAGE_GLSL_VK_4_6:
     case GPU_LANGUAGE_GLSL_ES_1_0:
     case GPU_LANGUAGE_GLSL_ES_3_0:
     case GPU_LANGUAGE_CG:
@@ -1207,7 +1278,7 @@ std::string GpuShaderText::float4GreaterThanEqual(const std::string& a,
         break;
     }
     case GPU_LANGUAGE_MSL_2_0:
-    case GPU_LANGUAGE_HLSL_DX11:
+    case GPU_LANGUAGE_HLSL_SM_5_0:
     {
         kw << float4Keyword() << "("
             << "(" << a << "[0] >= " << b << "[0]) ? 1.0 : 0.0, "
@@ -1244,6 +1315,7 @@ std::string GpuShaderText::atan2(const std::string & y,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -1251,7 +1323,7 @@ std::string GpuShaderText::atan2(const std::string & y,
             kw << "atan(" << y << ", " << x << ")";
             break;
         }
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             // note: Various internet sources claim that the x & y arguments need to be
             // swapped for HLSL (relative to GLSL).  However, recent testing on Windows
@@ -1283,9 +1355,10 @@ std::string GpuShaderText::sign(const std::string & v) const
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
-        case GPU_LANGUAGE_HLSL_DX11:
+        case GPU_LANGUAGE_HLSL_SM_5_0:
         case GPU_LANGUAGE_MSL_2_0:
         {
             kw << "sign(" << v << ");";
@@ -1305,6 +1378,15 @@ std::string GpuShaderText::sign(const std::string & v) const
     return kw.str();
 }
 
+std::string GpuShaderText::castToBool(const std::string& v) const
+{
+    if (m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        return "bool(" + v + ")";
+    }
+    return v;
+}
+
 
 std::string BuildResourceName(GpuShaderCreatorRcPtr & shaderCreator, const std::string & prefix,
                               const std::string & base)
@@ -1346,6 +1428,25 @@ void AddLinToLogShader(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st
     st.newLine() << "}";
 }
 
+void AddLinToLogShaderChannelBlue(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st)
+{
+    const std::string pix(shaderCreator->getPixelName());
+
+    st.newLine() << "{";   // establish scope so local variable names won't conflict
+    st.indent();
+    st.newLine() << st.floatKeywordConst() << " xbrk = 0.0041318374739483946;";
+    st.newLine() << st.floatKeywordConst() << " shift = -0.000157849851665374;";
+    st.newLine() << st.floatKeywordConst() << " m = 1. / (0.18 + shift);";
+    st.newLine() << st.floatKeywordConst() << " base2 = 1.4426950408889634;";  // 1/log(2)
+    st.newLine() << st.floatKeywordConst() << " gain = 363.034608563;";
+    st.newLine() << st.floatKeywordConst() << " offs = -7.;";
+    st.newLine() << st.float3Decl("ylin") << " = " << pix << ".rgb * gain + offs;";
+    st.newLine() << st.float3Decl("ylog") << " = base2 * log( ( " << pix << ".rgb + shift ) * m );";
+    st.newLine() << pix << ".rgb.b = (" << pix << ".rgb.b < xbrk) ? ylin.z : ylog.z;";
+    st.dedent();
+    st.newLine() << "}";
+}
+
 void AddLogToLinShader(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st)
 {
     const std::string pix(shaderCreator->getPixelName());
@@ -1366,4 +1467,22 @@ void AddLogToLinShader(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st
     st.newLine() << "}";
 }
 
+void AddLogToLinShaderChannelBlue(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st)
+{
+    const std::string pix(shaderCreator->getPixelName());
+
+    st.newLine() << "{";   // establish scope so local variable names won't conflict
+    st.indent();
+    st.newLine() << st.floatKeywordConst() << " ybrk = -5.5;";
+    st.newLine() << st.floatKeywordConst() << " shift = -0.000157849851665374;";
+    st.newLine() << st.floatKeywordConst() << " gain = 363.034608563;";
+    st.newLine() << st.floatKeywordConst() << " offs = -7.;";
+    st.newLine() << st.float3Decl("xlin") << " = (" << pix << ".rgb - offs) / gain;";
+    st.newLine() << st.float3Decl("xlog") << " = pow( " << st.float3Const(2.0f)
+                                          <<          ", " << pix << ".rgb ) * (0.18 + shift) - shift;";
+    st.newLine() << pix << ".rgb.b = (" << pix << ".rgb.b < ybrk) ? xlin.z : xlog.z;";
+    st.dedent();
+    st.newLine() << "}";
+}
+
 } // namespace OCIO_NAMESPACE
