@@ -6,6 +6,7 @@
 #include <fstream>
 #include <set>
 #include <vector>
+#include <algorithm>
 
 #include <OpenColorIO/OpenColorIO.h>
 namespace OCIO = OCIO_NAMESPACE;
@@ -26,10 +27,88 @@ const char * DESC_STRING = "\n\n"
 "Ociocheck can also be used to clean up formatting on an existing profile\n"
 "that has been manually edited, using the '-o' option.\n";
 
+
+// Returns true if the interopID is valid.
+bool isValidInteropID(const std::string& id)
+{
+    // See https://github.com/AcademySoftwareFoundation/ColorInterop for the details.
+
+    static const std::set<std::string> cifTextureIDs = {
+        "lin_ap1_scene",
+        "lin_ap0_scene",
+        "lin_rec709_scene",
+        "lin_p3d65_scene",
+        "lin_rec2020_scene",
+        "lin_adobergb_scene",
+        "lin_ciexyzd65_scene",
+        "srgb_rec709_scene",
+        "g22_rec709_scene",
+        "g18_rec709_scene",
+        "srgb_ap1_scene",
+        "g22_ap1_scene",
+        "srgb_p3d65_scene",
+        "g22_adobergb_scene",
+        "data",
+        "unknown"
+    };
+
+    static const std::set<std::string> cifDisplayIDs = {
+        "srgb_rec709_display",
+        "g24_rec709_display",
+        "srgb_p3d65_display",
+        "srgbe_p3d65_display",
+        "pq_p3d65_display",
+        "pq_rec2020_display",
+        "hlg_rec2020_display",
+        "g22_rec709_display",
+        "g22_adobergb_display",
+        "g26_p3d65_display",
+        "g26_xyzd65_display",
+        "pq_xyzd65_display",
+    };
+
+    if (id.empty()) 
+        return true;
+
+    // Check if the ID has a namespace.
+    size_t pos = id.find(':');
+    if (pos == std::string::npos) 
+    {
+        // No namespace, so the ID must be in the Color Interop Forum ID list.
+        if (cifTextureIDs.count(id) == 0 && cifDisplayIDs.count(id)==0)
+        {
+            std::cout << "WARNING: InteropID '" << id << "' is not valid. "
+                "It should either be one of the Color Interop Forum standard IDs or "
+                "it must contain a namespace followed by ':', e.g. 'mycompany:mycolorspace'." << 
+                std::endl;
+            return false;
+        }
+    }
+    else
+    {
+        // Namespace found, split into namespace and ID.
+        std::string ns = id.substr(0, pos);
+        std::string cs = id.substr(pos+1);
+
+        // The ID should not be in the Color Interop Forum ID list.
+        if (cifTextureIDs.count(cs) > 0 || cifDisplayIDs.count(cs)> 0) 
+        {
+            std::cout << "WARNING: InteropID '" << id << "' is not valid. "
+                "The ID part must not be one of the Color Interop Forum standard IDs "
+                "when a namespace is used." << std::endl;
+            return false;
+        }
+    }
+
+    // All clear.
+    return true;
+}
+
 int main(int argc, const char **argv)
 {
     bool help = false;
     int errorcount = 0;
+    int warningcount = 0;
     std::string inputconfig;
     std::string outputconfig;
 
@@ -279,6 +358,7 @@ int main(int argc, const char **argv)
                 if(!cs)
                 {
                     std::cout << "WARNING: NOT DEFINED (" << role << ")" << std::endl;
+                    warningcount += 1;
                 }
             }
         }
@@ -291,6 +371,9 @@ int main(int argc, const char **argv)
                 OCIO::SEARCH_REFERENCE_SPACE_ALL,   // Iterate over scene & display color spaces.
                 OCIO::COLORSPACE_ALL);              // Iterate over active & inactive color spaces.
 
+            bool foundCategory = false;
+            bool foundNoCategory = false;
+
             for(int i=0; i<numCS; ++i)
             {
                 OCIO::ConstColorSpaceRcPtr cs = config->getColorSpace(config->getColorSpaceNameByIndex(
@@ -298,6 +381,21 @@ int main(int argc, const char **argv)
                     OCIO::COLORSPACE_ALL,
                     i));
 
+                std::string interopID = cs->getInteropID();
+                if (!interopID.empty())
+                {
+                    if (!isValidInteropID(interopID))
+                    {
+                        warningcount += 1;
+                    }
+                }
+
+                if(!config->isInactiveColorSpace(cs->getName()))
+                {
+                    if(cs->getNumCategories() > 0) foundCategory = true;
+                    else foundNoCategory = true;
+                }
+
                 // Try to load the transform for the to_ref direction -- this will load any LUTs.
                 bool toRefOK = true;
                 std::string toRefErrorText;
@@ -353,6 +451,14 @@ int main(int argc, const char **argv)
                     std::cout << cs->getName() << std::endl;
                 }
             }
+
+            if(foundCategory && foundNoCategory)
+            {
+                // Categories should either be missing in all, or present in all active items.
+                std::cout << "\nWARNING: The config has some color spaces "
+                             "where the categories are not set.\n";
+                warningcount += 1;
+            }
         }
 
         {
@@ -366,11 +472,20 @@ int main(int argc, const char **argv)
                 std::cout << "no named transforms defined" << std::endl;
             }
 
+            bool foundCategory = false;
+            bool foundNoCategory = false;
+
             for(int i = 0; i<numNT; ++i)
             {
                 OCIO::ConstNamedTransformRcPtr nt = config->getNamedTransform(
                     config->getNamedTransformNameByIndex(OCIO::NAMEDTRANSFORM_ALL, i));
 
+                if(!config->isInactiveColorSpace(nt->getName()))
+                {
+                    if(nt->getNumCategories() > 0) foundCategory = true;
+                    else foundNoCategory = true;
+                }
+
                 // Try to load the transform -- this will load any LUTs.
                 bool fwdOK = true;
                 std::string fwdErrorText;
@@ -426,6 +541,14 @@ int main(int argc, const char **argv)
                     std::cout << nt->getName() << std::endl;
                 }
             }
+
+            if(foundCategory && foundNoCategory)
+            {
+                // Categories should either be missing in all, or present in all active items.
+                std::cout << "\nWARNING: The config has some named transforms "
+                             "where the categories are not set.\n";
+                warningcount += 1;
+            }
         }
 
         {
@@ -518,11 +641,11 @@ int main(int argc, const char **argv)
             StringUtils::StringVec svec = StringUtils::SplitByLines(logGuard.output());
             if (!StringUtils::Contain(svec, "[OpenColorIO Error]"))
             {
-                std::cout << "passed" << std::endl;
+                std::cout << "Validation: passed" << std::endl;
             }
             else
             {
-                std::cout << "failed" << std::endl;
+                std::cout << "Validation: failed" << std::endl;
                 errorcount += 1;
             }
         }
@@ -531,7 +654,7 @@ int main(int argc, const char **argv)
             std::cout << "ERROR:" << std::endl;
             errorcount += 1;
             std::cout << exception.what() << std::endl;
-            std::cout << "failed" << std::endl;
+            std::cout << "Validation: failed" << std::endl;
         }
 
         std::cout << std::endl;
@@ -570,6 +693,11 @@ int main(int argc, const char **argv)
         return 1;
     }
 
+    if(warningcount > 0)
+    {
+        std::cout << "\nWarnings encountered: " << warningcount << std::endl;
+    }
+
     std::cout << std::endl;
     if(errorcount == 0)
     {
